@@ -18,7 +18,7 @@
  
      For further information visit http://plib.sourceforge.net
 
-     $Id: slPortability.h,v 1.11 2002/09/02 06:05:47 sjbaker Exp $
+     $Id: slPortability.h 2013 2005-01-16 06:03:31Z sjbaker $
 */
 
 
@@ -33,13 +33,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-/* the next lines are to define BSD */
-/* see http://www.freebsd.org/handbook/porting.html for why we do this */
-#if (defined(__unix__) || defined(unix)) && !defined(USG)
-#include <sys/param.h>
-#endif
-
-#ifdef macintosh
+#ifdef UL_MACINTOSH
   #include <Sound.h>
   #include <Timer.h>
   #ifdef __MWERKS__
@@ -47,38 +41,26 @@
   #endif
 #endif
 
-#ifdef __APPLE__
+#ifdef UL_MAC_OSX
   #include <Carbon/Carbon.h>
 #endif
 
-#ifndef  WIN32
-#include <unistd.h>
-#include <sys/ioctl.h>
-#else
-#include <windows.h>
-#ifdef __CYGWIN32__
-#  define NEAR /* */
-#  define FAR  /* */
-#  define WHERE_EVER_YOU_ARE /* Curt: optional, but it reminds me of a song */
-#endif
-#include <mmsystem.h>
-#endif
-
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <string.h>
 #include <limits.h>
 #include <math.h>
 
-#if (defined(__linux__) || defined(BSD)) && !defined(__NetBSD__)
+#if (defined(UL_LINUX) || defined(UL_BSD)) && !defined(__NetBSD__) && !defined(__OpenBSD__)
 #define SL_USING_OSS_AUDIO 1
 #endif
 
 #ifdef SL_USING_OSS_AUDIO
-#  if defined(__linux__)
+#  if defined(UL_LINUX)
 #    include <linux/soundcard.h>
+#    include <sys/ioctl.h>
 #  elif defined(__FreeBSD__)
-#    include <machine/soundcard.h>
+#    include <sys/soundcard.h>
 #  else
     /*
       Tom thinks this file may be <sys/soundcard.h> under some
@@ -92,20 +74,21 @@
 #  endif
 #endif
 
-#if defined (__NetBSD__) || defined(__OpenBSD__)
+#ifdef UL_BSD
+#ifndef __FreeBSD__
 #  include <sys/audioio.h>
 #endif
+#endif
 
 /* Tom */
 
-#ifdef	sgi
+#ifdef UL_IRIX
 #  include <audio.h>
 #endif
 
-#if defined(__svr4__) || defined(__SVR4)
+#ifdef UL_SOLARIS
 #  include <sys/audioio.h>
 #  include <sys/stropts.h>
-#  define SOLARIS
 #endif
 
 #endif
